#
# spec file for package python-inspektor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{suse_version} >= 1550
# cliff and stevedore are only built for primary python3
%define pythons python3
%endif
%global         pkgname inspektor
Name:           python-%{pkgname}
Version:        0.5.2
Release:        3.3
Summary:        Program used to verify the code of your python project
License:        GPL-2.0-only
URL:            https://github.com/avocado-framework/inspektor
Source:         https://files.pythonhosted.org/packages/42/8a/9e375ac0bb498760fe2408a2e0f1fe09808933e593d1b6f04193492b9048/inspektor-%{version}.tar.gz
BuildRequires:  %{python_module astroid >= 1.2.1}
BuildRequires:  %{python_module cmd2}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module logutils >= 0.3.3}
BuildRequires:  %{python_module pbr >= 1.4}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pycodestyle >= 2.0.0}
BuildRequires:  %{python_module pylint >= 1.3.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-cliff
BuildRequires:  python3-stevedore
Requires:       python-cliff
Requires:       python-pycodestyle >= 2.0.0
Requires:       python-pylint >= 1.3.1
Requires:       python-six
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Inspektor is a program used to verify the code of a Python project.
It checks code with the help of pylint, checks indentation with
pycodestyle, and checks for PEP8 compliance.

Inspektor can work with Git and SVN checkouts.

%prep
%setup -q -n %{pkgname}-%{version}

%build
%pyproject_wheel

%check
# No test suite

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/inspekt
%fdupes %{buildroot}

%post
%python_install_alternative inspekt

%postun
%python_uninstall_alternative inspekt

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/inspekt
%{python_sitelib}/%{pkgname}
%{python_sitelib}/%{pkgname}-%{version}.dist-info

%changelog
* Wed Oct  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Clean up {Build,}Requires.
- No more greedy globs in %%files.
* Thu Apr 29 2021 Benjamin Greiner <code@bnavigator.de>
- Only build for primary python3
* Wed Apr 14 2021 Steve Kowalik <steven.kowalik@suse.com>
- Only build for 3.8, some depends only built there.
- There is no test suite, remove trying to run it.
- Remove broken %%ifpython3 macro.
* Tue Apr 16 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.5.2
  * No changelog available
- Use pypi url for source
* Wed Jan  2 2019 Martin Pluskal <mpluskal@suse.com>
- Do not run tests on old distributions
* Tue Oct  9 2018 Martin Pluskal <mpluskal@suse.com>
- Update dependencies to match latest python packaging changes
* Fri Jul 27 2018 mpluskal@suse.com
- Update to version 0.5.1:
  * No changelog available
* Sun Oct  8 2017 jengelh@inai.de
- Remove history lesson from description.
* Thu Oct  5 2017 mpluskal@suse.com
- Initial package for version 0.4.5
